@@ -15,8 +15,8 @@ impl CLI {
         }
     }
 
-    pub fn println<S: AsRef<str>>(&mut self, msg: S) {
-        println!("[{}] {}", self.title, msg.as_ref().to_string());
+    pub fn println<S: AsRef<str>>(&mut self, title: S, msg: S) {
+        println!("[{}] {}: {}", self.title, title.as_ref(), msg.as_ref());
         match stdout().flush() {
             Ok(ok) => ok,
             Err(_err) => ()
@@ -25,8 +25,8 @@ impl CLI {
         self.history.push(msg.as_ref().to_string());
     }
 
-    pub fn eprintln<S: AsRef<str>>(&mut self, msg: S) {
-        eprintln!("[{} \x1B[31;1merror\x1B[0;0m] {}", self.title, msg.as_ref().to_string());
+    pub fn eprintln<S: AsRef<str>>(&mut self, title: S, msg: S) {
+        eprintln!("[{} \x1B[31;1merror\x1B[0;0m] {}: {}", self.title, title.as_ref(), msg.as_ref());
         match stderr().flush() {
             Ok(ok) => ok,
             Err(_err) => ()
