@@ -30,8 +30,8 @@ mod tests {
     fn test_cli() {
         let mut cli = CLI::new("test_cli");
 
-        cli.println("message");
-        cli.eprintln("message");
+        cli.println("title", "message");
+        cli.eprintln("title", "message");
 
         assert_eq!(cli.clone_history(), vec!["message".to_string(), "message".to_string()]);
     }
